@@ -55,12 +55,15 @@ typedef struct SmalltalkClosure
   OOP      widget;
 } SmalltalkClosure;
 
-VMProxy *_blox_vm_proxy;
+VMProxy *_gst_vm_proxy;
 
 static GQuark q_gst_object = 0;
 static int pending_quit_count = 0;
 
-static void blox_gtk_init ();
+static void gst_gtk_init ();
+
+/* Start the main event loop and then signal OOP.  */
+static void my_gtk_main (OOP semaphore);
 
 /* Wait in the main event loop until there are no pending events.  */
 static void my_gtk_main_iteration ();
@@ -155,22 +158,11 @@ static void container_set_child_property (GtkContainer *aParent,
 					  const char *aProperty,
 					  OOP aValue);
 
-/* Some wrappers for GTK macros.  */
-static GdkWindow *widget_get_window(GtkWidget *widget);
-
-static int widget_get_flags(GtkWidget *widget);
-
-static void widget_set_flags(GtkWidget *widget,
-			     int flags);
-
-static void widget_unset_flags(GtkWidget *widget,
-			       int flags);
-
 /* GObject wrapper.  */
 void
 register_for_type (OOP oop, GType type)
 {
-  _blox_vm_proxy->registerOOP (oop);
+  _gst_vm_proxy->registerOOP (oop);
   g_type_set_qdata (type, q_gst_object, oop);
 }
 
@@ -191,7 +183,7 @@ associate_oop_to_g_object (GObject *obj, OOP oop)
 
   g_object_set_qdata (obj, q_gst_object, oop);
   g_object_ref (obj);
-  _blox_vm_proxy->strMsgSend (oop, "addToBeFinalized", NULL);
+  _gst_vm_proxy->strMsgSend (oop, "addToBeFinalized", NULL);
 }
 
 OOP
@@ -210,7 +202,7 @@ narrow_oop_for_g_object (GObject *obj, OOP oop)
 OOP
 get_oop_for_g_boxed (gpointer obj, GType type)
 {
-  OOP oop = _blox_vm_proxy->cObjectToOOP(obj);
+  OOP oop = _gst_vm_proxy->cObjectToOOP(obj);
   OOP class = g_type_get_qdata (type, q_gst_object);
 
   if (class)
@@ -227,7 +219,7 @@ get_oop_for_g_object (GObject *obj)
     {
       /* We don't have a wrapper for it, so create it.  Get the class
 	 from the object's type.  */
-      oop = _blox_vm_proxy->cObjectToOOP(obj);
+      oop = _gst_vm_proxy->cObjectToOOP(obj);
       associate_oop_to_g_object (obj, oop);
     }
 
@@ -256,55 +248,55 @@ convert_g_value_to_oop (const GValue *val)
     {
     case G_TYPE_CHAR:
       v_char = g_value_get_char (val);
-      return _blox_vm_proxy->charToOOP(v_char);
+      return _gst_vm_proxy->charToOOP(v_char);
 
     case G_TYPE_BOOLEAN:
       v_boolean = g_value_get_boolean (val);
-      return _blox_vm_proxy->boolToOOP(v_boolean);
+      return _gst_vm_proxy->boolToOOP(v_boolean);
 
     case G_TYPE_UCHAR:
       v_int = g_value_get_uchar (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_INT:
       v_int = g_value_get_int (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_UINT:
       v_int = g_value_get_uint (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_LONG:
       v_int = g_value_get_long (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_ULONG:
       v_int = g_value_get_ulong (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_ENUM:
       v_int = g_value_get_enum (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_FLAGS:
       v_int = g_value_get_flags (val);
-      return _blox_vm_proxy->intToOOP(v_int);
+      return _gst_vm_proxy->intToOOP(v_int);
 
     case G_TYPE_FLOAT:
       v_float = g_value_get_float (val);
-      return _blox_vm_proxy->floatToOOP(v_float);
+      return _gst_vm_proxy->floatToOOP(v_float);
 
     case G_TYPE_DOUBLE:
       v_float = g_value_get_double (val);
-      return _blox_vm_proxy->floatToOOP(v_float);
+      return _gst_vm_proxy->floatToOOP(v_float);
 
     case G_TYPE_STRING:
       v_ptr = (gpointer) g_value_get_string (val);
-      return _blox_vm_proxy->stringToOOP(v_ptr);
+      return _gst_vm_proxy->stringToOOP(v_ptr);
 
     case G_TYPE_POINTER:
       v_ptr = g_value_get_pointer (val);
-      return _blox_vm_proxy->cObjectToOOP(v_ptr);
+      return _gst_vm_proxy->cObjectToOOP(v_ptr);
 
     case G_TYPE_BOXED:
       v_ptr = g_value_get_boxed (val);
@@ -346,78 +338,78 @@ fill_g_value_from_oop (GValue *return_value, OOP oop)
       break;
 
     case G_TYPE_CHAR:
-      v_char = _blox_vm_proxy->OOPToChar(oop);
+      v_char = _gst_vm_proxy->OOPToChar(oop);
       g_value_set_char (return_value, v_char);
       break;
 
     case G_TYPE_BOOLEAN:
-      v_boolean = _blox_vm_proxy->OOPToBool(oop);
+      v_boolean = _gst_vm_proxy->OOPToBool(oop);
       g_value_set_boolean (return_value, v_boolean);
       break;
 
     case G_TYPE_UCHAR:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_uchar (return_value, v_int);
       break;
 
     case G_TYPE_INT:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_int (return_value, v_int);
       break;
 
     case G_TYPE_UINT:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_uint (return_value, v_int);
       break;
 
     case G_TYPE_LONG:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_long (return_value, v_int);
       break;
 
     case G_TYPE_ULONG:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_ulong (return_value, v_int);
       break;
 
     case G_TYPE_ENUM:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_enum (return_value, v_int);
       break;
 
     case G_TYPE_FLAGS:
-      v_int = _blox_vm_proxy->OOPToInt(oop);
+      v_int = _gst_vm_proxy->OOPToInt(oop);
       g_value_set_flags (return_value, v_int);
       break;
 
     case G_TYPE_FLOAT:
-      v_float = _blox_vm_proxy->OOPToFloat(oop);
+      v_float = _gst_vm_proxy->OOPToFloat(oop);
       g_value_set_float (return_value, v_float);
       break;
 
     case G_TYPE_DOUBLE:
-      v_float = _blox_vm_proxy->OOPToFloat(oop);
+      v_float = _gst_vm_proxy->OOPToFloat(oop);
       g_value_set_double (return_value, v_float);
       break;
 
     case G_TYPE_STRING:
-      v_ptr = _blox_vm_proxy->OOPToString(oop);
+      v_ptr = _gst_vm_proxy->OOPToString(oop);
       g_value_set_string_take_ownership (return_value, v_ptr);
       break;
 
     case G_TYPE_POINTER:
-      v_ptr = _blox_vm_proxy->OOPToCObject(oop);
+      v_ptr = _gst_vm_proxy->OOPToCObject(oop);
       g_value_set_pointer (return_value, v_ptr);
       break;
 
     case G_TYPE_BOXED:
-      v_ptr = _blox_vm_proxy->OOPToCObject(oop);
+      v_ptr = _gst_vm_proxy->OOPToCObject(oop);
       g_value_set_boxed (return_value, v_ptr);
       break;
 
     case G_TYPE_OBJECT:
     case G_TYPE_INTERFACE:
-      v_ptr = _blox_vm_proxy->OOPToCObject(oop);
+      v_ptr = _gst_vm_proxy->OOPToCObject(oop);
       g_value_set_object (return_value, v_ptr);
       break;
 
@@ -435,8 +427,8 @@ create_smalltalk_closure(OOP receiver,
   GClosure *closure = g_closure_new_simple (sizeof (SmalltalkClosure), NULL);
   SmalltalkClosure *stc = (SmalltalkClosure *) closure;
 
-  _blox_vm_proxy->registerOOP (receiver);
-  _blox_vm_proxy->registerOOP (data);
+  _gst_vm_proxy->registerOOP (receiver);
+  _gst_vm_proxy->registerOOP (data);
 
   stc->receiver = receiver;
   stc->selector = selector;
@@ -453,8 +445,8 @@ finalize_smalltalk_closure(gpointer      data,
 {
   SmalltalkClosure *stc = (SmalltalkClosure *) closure;
 
-  _blox_vm_proxy->unregisterOOP (stc->receiver);
-  _blox_vm_proxy->unregisterOOP (stc->data);
+  _gst_vm_proxy->unregisterOOP (stc->receiver);
+  _gst_vm_proxy->unregisterOOP (stc->data);
 }
 
 void
@@ -488,7 +480,7 @@ invoke_smalltalk_closure(GClosure     *closure,
     }
   args[n_param_values] = stc->data;
 
-  resultOOP = _blox_vm_proxy->nvmsgSend(stc->receiver, stc->selector, args,
+  resultOOP = _gst_vm_proxy->nvmsgSend(stc->receiver, stc->selector, args,
 					1 + n_param_values);
 
   /* FIXME Need to init return_value's type? */
@@ -496,7 +488,7 @@ invoke_smalltalk_closure(GClosure     *closure,
     fill_g_value_from_oop (return_value, resultOOP);
 }
 
-/* Signal implementation */
+/* Signal implementation.  */
 int
 connect_signal (OOP widget, 
 		char *event_name, 
@@ -504,27 +496,27 @@ connect_signal (OOP widget,
 		OOP selector,
 		OOP user_data)
 {
-  GtkWidget    *cWidget = _blox_vm_proxy->OOPToCObject (widget);
+  GtkWidget    *cWidget = _gst_vm_proxy->OOPToCObject (widget);
   GClosure     *closure;
   GSignalQuery  qry;
   guint         sig_id;
   OOP           oop_sel_args;
 
   /* Check parameters */
-  if (!G_IS_OBJECT(cWidget)) { return(-1); } /* Invalid widget passed */
+  if (!G_IS_OBJECT(cWidget)) { return (-1); } /* Invalid widget passed */
   sig_id = g_signal_lookup(event_name, G_OBJECT_TYPE(G_OBJECT(cWidget)));
-  if (sig_id = 0) { return(-2); } /* Invalid event name */
+  if (sig_id = 0) { return (-2); } /* Invalid event name */
 
   g_signal_query(sig_id, &qry);
-  oop_sel_args = _blox_vm_proxy->strMsgSend(selector, "numArgs", NULL);
-  if (oop_sel_args == _blox_vm_proxy->nilOOP) { return(-3); } /* Invalid selector */ 
+  oop_sel_args = _gst_vm_proxy->strMsgSend(selector, "numArgs", NULL);
+  if (oop_sel_args == _gst_vm_proxy->nilOOP) { return (-3); } /* Invalid selector */ 
 
   /* Check the number of arguments in the selector against the number of 
      arguments in the event callback */
   /* We can return fewer arguments than are in the event, if the others aren't 
      wanted, but we can't return more, and returning nilOOPs instead is not 
      100% satisfactory, so fail. */
-  if (_blox_vm_proxy->OOPToInt(oop_sel_args) > qry.n_params) { return(-4); }
+  if (_gst_vm_proxy->OOPToInt(oop_sel_args) > qry.n_params) { return (-4); }
 
   /* Receiver is assumed to be OK, no matter what it is */
   /* Parameters OK, so carry on and connect the signal */
@@ -533,22 +525,46 @@ connect_signal (OOP widget,
 
   closure = create_smalltalk_closure (receiver, selector, user_data);
   g_signal_connect_closure (cWidget, event_name, closure, FALSE);
-  return(0);
+  return (0);
+}
+
+/* Event loop.  The GTK+ event loop in GNU Smalltalk takes place
+   using my_gtk_main_iteration in a separate process.  GtkImpl.st
+   redefines Gtk class>>#main calling this function: the event
+   loop process is sitting on SEMAPHORE, so that after the first event
+   is delivered, SEMAPHORE is unblocked and the real event loop
+   takes place in the semaphore process.  */
+
+void
+my_gtk_main (OOP semaphore)
+{
+  _gst_vm_proxy->registerOOP (semaphore);
+  _gst_vm_proxy->asyncSignalAndUnregister (semaphore);
+  gtk_main ();
 }
 
-/* Event loop.  */
 void
 my_gtk_main_iteration ()
 {
+  int pending_quit = FALSE;
   while (gtk_events_pending ())
-    pending_quit_count += gtk_main_iteration_do (TRUE);
+    if (gtk_main_iteration_do (TRUE))
+      {
+	pending_quit_count += !pending_quit;
+	pending_quit = TRUE;
+      }
 }
 
 void
 my_gtk_main_iteration_do (gboolean blocking)
 {
+  int pending_quit = FALSE;
   while (gtk_events_pending ())
-    pending_quit_count += gtk_main_iteration_do (blocking);
+    if (gtk_main_iteration_do (blocking))
+      {
+	pending_quit_count += !pending_quit;
+	pending_quit = TRUE;
+      }
 }
 
 gboolean
@@ -561,31 +577,6 @@ should_quit ()
   return TRUE;
 }
 
-/* Wrappers for macros.  */
-GdkWindow *
-widget_get_window(GtkWidget *widget)
-{
-  return widget->window;
-}
-
-int
-widget_get_flags(GtkWidget *widget)
-{
-  return GTK_WIDGET_FLAGS (widget);
-}
-
-void
-widget_set_flags(GtkWidget *widget, int flags)
-{
-  GTK_WIDGET_SET_FLAGS (widget, flags);
-}
-
-void
-widget_unset_flags(GtkWidget *widget, int flags)
-{
-  GTK_WIDGET_UNSET_FLAGS (widget, flags);
-}
-
 /* Wrappers for GValue users.  */
 OOP
 object_get_property(GObject *anObject, const char *aProperty)
@@ -623,7 +614,7 @@ container_get_child_property(GtkContainer *aParent, GtkWidget *aChild, const cha
 
   g_return_val_if_fail (GTK_WIDGET (aParent) ==
 		        gtk_widget_get_parent (GTK_WIDGET (aChild)),
-			_blox_vm_proxy->nilOOP);
+			_gst_vm_proxy->nilOOP);
 
   spec = gtk_container_class_find_child_property (G_OBJECT_GET_CLASS (aParent),
 					          aProperty);
@@ -650,38 +641,8 @@ container_set_child_property(GtkContainer *aParent, GtkWidget *aChild, const cha
   gtk_container_child_set_property(aParent, aChild, aProperty, &value);
 }
 
-
-/* Initialization.  */
-
-void
-blox_gtk_init ()
-{
-  static int init = 0;
-  int argc = 1;
-  gchar *argvArray[] = { "gst", NULL };
-  gchar **argv = argvArray;
-
-  if (init)
-    return;
-
-  init++;
-  gtk_init (&argc, &argv);
-}
-
-int 
-gtk_text_iter_sizeof ()
-{
-  return(sizeof(GtkTextIter));
-}
-
-int 
-gtk_tree_iter_sizeof ()
-{
-  return(sizeof(GtkTreeIter));
-}
-
 OOP 
-gtk_tree_model_get_oop(GtkTreeModel *model, GtkTreeIter *iter, int col) 
+tree_model_get_oop(GtkTreeModel *model, GtkTreeIter *iter, int col) 
 { 
   GValue gval = { 0, }; 
   OOP result; 
@@ -689,11 +650,11 @@ gtk_tree_model_get_oop(GtkTreeModel *model, GtkTreeIter *iter, int col)
   gtk_tree_model_get_value(model, iter, col, &gval); 
   result = convert_g_value_to_oop(&gval);
   g_value_unset(&gval);
-  return(result); 
+  return (result); 
 } 
 
 void 
-gtk_list_store_set_oop(GtkListStore *store, GtkTreeIter *iter, int col, OOP value) 
+list_store_set_oop(GtkListStore *store, GtkTreeIter *iter, int col, OOP value) 
 { 
     GValue gval = { 0, };
     g_value_init (&gval, gtk_tree_model_get_column_type(GTK_TREE_MODEL(store), col));
@@ -703,7 +664,7 @@ gtk_list_store_set_oop(GtkListStore *store, GtkTreeIter *iter, int col, OOP valu
 } 
 
 void 
-gtk_tree_store_set_oop(GtkTreeStore *store, GtkTreeIter *iter, int col, OOP value) 
+tree_store_set_oop(GtkTreeStore *store, GtkTreeIter *iter, int col, OOP value) 
 { 
     GValue gval = { 0, }; 
     g_value_init (&gval, gtk_tree_model_get_column_type(GTK_TREE_MODEL(store), col));
@@ -712,6 +673,105 @@ gtk_tree_store_set_oop(GtkTreeStore *store, GtkTreeIter *iter, int col, OOP valu
     g_value_unset(&gval);
 }
 
+
+/* Wrappers for macros and missing accessor functions.  */
+
+static GdkWindow *
+widget_get_window(GtkWidget *widget)
+{
+  return widget->window;
+}
+
+static int
+widget_get_state(GtkWidget *widget)
+{
+  return GTK_WIDGET_STATE (widget);
+}
+
+static int
+widget_get_flags(GtkWidget *widget)
+{
+  return GTK_WIDGET_FLAGS (widget);
+}
+
+static void
+widget_set_flags(GtkWidget *widget, int flags)
+{
+  GTK_WIDGET_SET_FLAGS (widget, flags);
+}
+
+static void
+widget_unset_flags(GtkWidget *widget, int flags)
+{
+  GTK_WIDGET_UNSET_FLAGS (widget, flags);
+}
+
+
+static GtkAllocation *
+widget_get_allocation(GtkWidget *wgt)
+{
+  return &(GTK_WIDGET(wgt)->allocation);
+}
+
+static GtkWidget *
+dialog_get_vbox(GtkDialog *dlg)
+{
+  return (GTK_DIALOG(dlg)->vbox);
+}
+
+static GtkWidget *
+dialog_get_action_area(GtkDialog *dlg)
+{
+  return (GTK_DIALOG(dlg)->action_area);
+}
+
+static int
+scrolled_window_get_hscrollbar_visible(GtkScrolledWindow *swnd)
+{
+  return (GTK_SCROLLED_WINDOW(swnd)->hscrollbar_visible);
+}
+
+static int
+scrolled_window_get_vscrollbar_visible(GtkScrolledWindow *swnd)
+{
+  return (GTK_SCROLLED_WINDOW(swnd)->vscrollbar_visible);
+}
+
+static int
+adjustment_get_lower(GtkAdjustment *adj)
+{
+  return (GTK_ADJUSTMENT(adj)->lower);
+}
+
+static int
+adjustment_get_upper(GtkAdjustment *adj)
+{
+  return (GTK_ADJUSTMENT(adj)->upper);
+}
+
+static int
+adjustment_get_page_size(GtkAdjustment *adj)
+{
+  return (GTK_ADJUSTMENT(adj)->page_size);
+}
+
+/* Initialization.  */
+
+void
+gst_gtk_init ()
+{
+  static int init = 0;
+  int argc = 1;
+  gchar *argvArray[] = { (char *) "gst", NULL };
+  gchar **argv = argvArray;
+
+  if (init)
+    return;
+
+  init++;
+  gtk_init (&argc, &argv);
+}
+
 void
 gst_initModule (proxy)
      VMProxy *proxy;
@@ -719,38 +779,44 @@ gst_initModule (proxy)
   q_gst_object = g_quark_from_string ("gst_object");
   g_type_init ();
 
-  _blox_vm_proxy = proxy;
-  _blox_vm_proxy->defineCFunc ("bloxGtkInit", blox_gtk_init);
-  _blox_vm_proxy->defineCFunc ("bloxGtkRegisterForType", register_for_type);
-  _blox_vm_proxy->defineCFunc ("bloxGtkFreeGObjectOOP", free_oop_for_g_object);
-  _blox_vm_proxy->defineCFunc ("bloxGtkNarrowGObjectOOP", narrow_oop_for_g_object);
-  _blox_vm_proxy->defineCFunc ("bloxGtkConnectSignal", connect_signal);
-  _blox_vm_proxy->defineCFunc ("bloxGtkMainIteration", my_gtk_main_iteration);
-  _blox_vm_proxy->defineCFunc ("bloxGtkMainIterationDo", my_gtk_main_iteration_do);
-  _blox_vm_proxy->defineCFunc ("bloxGtkShouldQuit", should_quit);
-  _blox_vm_proxy->defineCFunc ("bloxGtkGetProperty", object_get_property);
-  _blox_vm_proxy->defineCFunc ("bloxGtkSetProperty", object_set_property);
-  _blox_vm_proxy->defineCFunc ("bloxGtkGetChildProperty", container_get_child_property);
-  _blox_vm_proxy->defineCFunc ("bloxGtkSetChildProperty", container_set_child_property);
-  _blox_vm_proxy->defineCFunc ("bloxGtkGetFlags", widget_get_flags);
-  _blox_vm_proxy->defineCFunc ("bloxGtkSetFlags", widget_set_flags);
-  _blox_vm_proxy->defineCFunc ("bloxGtkUnsetFlags", widget_unset_flags);
-  _blox_vm_proxy->defineCFunc ("bloxGtkGetWindow", widget_get_window);
+  _gst_vm_proxy = proxy;
+  _gst_vm_proxy->defineCFunc ("gstGtkInit", gst_gtk_init);
+  _gst_vm_proxy->defineCFunc ("gstGtkRegisterForType", register_for_type);
+  _gst_vm_proxy->defineCFunc ("gstGtkFreeGObjectOOP", free_oop_for_g_object);
+  _gst_vm_proxy->defineCFunc ("gstGtkNarrowGObjectOOP", narrow_oop_for_g_object);
+  _gst_vm_proxy->defineCFunc ("gstGtkConnectSignal", connect_signal);
+  _gst_vm_proxy->defineCFunc ("gstGtkMain", my_gtk_main);
+  _gst_vm_proxy->defineCFunc ("gstGtkMainIteration", my_gtk_main_iteration);
+  _gst_vm_proxy->defineCFunc ("gstGtkMainIterationDo", my_gtk_main_iteration_do);
+  _gst_vm_proxy->defineCFunc ("gstGtkShouldQuit", should_quit);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetProperty", object_get_property);
+  _gst_vm_proxy->defineCFunc ("gstGtkSetProperty", object_set_property);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetChildProperty", container_get_child_property);
+  _gst_vm_proxy->defineCFunc ("gstGtkSetChildProperty", container_set_child_property);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetState", widget_get_state);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetFlags", widget_get_flags);
+  _gst_vm_proxy->defineCFunc ("gstGtkSetFlags", widget_set_flags);
+  _gst_vm_proxy->defineCFunc ("gstGtkUnsetFlags", widget_unset_flags);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetWindow", widget_get_window);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetHscrollbarVisible", scrolled_window_get_hscrollbar_visible);
+  _gst_vm_proxy->defineCFunc ("gstGtkGetVscrollbarVisible", scrolled_window_get_vscrollbar_visible);
+  _gst_vm_proxy->defineCFunc ("gstGtkAdjustmentGetLower", adjustment_get_lower);
+  _gst_vm_proxy->defineCFunc ("gstGtkAdjustmentGetUpper", adjustment_get_upper);
+  _gst_vm_proxy->defineCFunc ("gstGtkAdjustmentGetPageSize", adjustment_get_page_size);
+  _gst_vm_proxy->defineCFunc ("gstGtkTreeModelGetOOP", tree_model_get_oop);
+  _gst_vm_proxy->defineCFunc ("gstGtkListStoreSetOOP", list_store_set_oop);
+  _gst_vm_proxy->defineCFunc ("gstGtkTreeStoreSetOOP", tree_store_set_oop);
+  _gst_vm_proxy->defineCFunc ("gstGtkWidgetGetAllocation", widget_get_allocation);
+  _gst_vm_proxy->defineCFunc ("gstGtkDialogGetVBox", dialog_get_vbox);
+  _gst_vm_proxy->defineCFunc ("gstGtkDialogGetActionArea", dialog_get_action_area);
 
-  /* Not yet in MoreFuncs.st.  */
-  _blox_vm_proxy->defineCFunc ("gtk_text_iter_sizeof", gtk_text_iter_sizeof);
-  _blox_vm_proxy->defineCFunc ("gtk_tree_iter_sizeof", gtk_tree_iter_sizeof);
-  _blox_vm_proxy->defineCFunc ("gtk_tree_model_get_oop", gtk_tree_model_get_oop);
-  _blox_vm_proxy->defineCFunc ("gtk_list_store_set_oop", gtk_list_store_set_oop);
-  _blox_vm_proxy->defineCFunc ("gtk_tree_store_set_oop", gtk_tree_store_set_oop);
-
-  _blox_vm_proxy->defineCFunc ("gtk_placer_get_type", gtk_placer_get_type);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_new", gtk_placer_new);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_put", gtk_placer_put);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_move", gtk_placer_move);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_resize", gtk_placer_resize);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_move_rel", gtk_placer_move_rel);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_resize_rel", gtk_placer_resize_rel);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_set_has_window", gtk_placer_set_has_window);
-  _blox_vm_proxy->defineCFunc ("gtk_placer_get_has_window", gtk_placer_get_has_window);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_get_type", gtk_placer_get_type);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_new", gtk_placer_new);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_put", gtk_placer_put);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_move", gtk_placer_move);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_resize", gtk_placer_resize);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_move_rel", gtk_placer_move_rel);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_resize_rel", gtk_placer_resize_rel);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_set_has_window", gtk_placer_set_has_window);
+  _gst_vm_proxy->defineCFunc ("gtk_placer_get_has_window", gtk_placer_get_has_window);
 }
