@@ -25,6 +25,10 @@
 #include <stdio.h>
 #include "avltrees.h"
 
+#ifdef STDC_HEADERS
+#include <stdlib.h>
+#endif
+
 #define HEIGHT(node)   (node ? node->avl_height : 0)
 
 void avl_rebalance (avl_node_t *node, avl_node_t **tree)
@@ -196,6 +200,18 @@ void avl_erase (avl_node_t *node, avl_node_t **tree)
   avl_rebalance(deepest->avl_parent, tree);
 }
 
+void
+avl_destroy(register avl_node_t *node)
+{
+  if (node->avl_left)
+    avl_destroy (node->avl_left);
+  
+  if (node->avl_right)
+    avl_destroy (node->avl_right);
+  
+  free (node);
+}
+  
 avl_node_t *
 avl_first(register avl_node_t *node, register avl_traverse_t *t)
 {
