@@ -33,14 +33,14 @@
 /* #define LOG_MEMORY_OPERATIONS */
 
 
-#define	SMALL2FREE(B, N)	((heap_freeobj*)(&(B)->vSmall.data[(N)*(B)->size]))
+#define SMALL2FREE(B, N)        ((heap_freeobj*)(((char *)(B)->vSmall.data) + (N)*(B)->size))
 
 #define	MEM2BLOCK(M)		((heap_block*)(((long)(M)) & -pagesize))
 #define	MEM2FREE(M)		((heap_freeobj*)(M))
 
 #define	BLOCKEND(B)		((heap_block*)(((unsigned char*)(B)) + (B)->size))
 
-#define	MAX_SMALL_OBJ_SIZE	8192
+#define	MAX_SMALL_OBJ_SIZE	16384
 #define	IS_SMALL_SIZE(S)	((S) <= max_small_object_size)
 
 #define	MEMALIGN		8
@@ -99,7 +99,9 @@ static unsigned short freelist_size[NUM_FREELISTS + 1] = {
   120, 128, 136, 144, 152, 160, 168, 176, 184, 192, 200,
   208, 224, 232, 248, 264, 288, 312, 336, 368, 400, 448,
   504, 576, 672, 808, 1016, 1352, 2032, 
-  4080 - 2*SIZEOF_CHAR_P, 0
+  4096 - SMALL_OBJ_HEADER_SIZE,
+  8192 - SMALL_OBJ_HEADER_SIZE,
+  16384 - SMALL_OBJ_HEADER_SIZE, 0
 };
 
 static unsigned short sztable[MAX_SMALL_OBJ_SIZE + 1];
@@ -131,7 +133,7 @@ init_heap (heap_data *h, size_t heap_allocation_size, size_t heap_limit)
 
       /* Use the preinitialized freelist table to initialize
          the sztable.  */
-      for (sz = i = 0; freelist_size[i] > 0; i++)
+      for (sz = i = 0; freelist_size[i] > 0 && freelist_size[i] < pagesize; i++)
         for (; sz <= freelist_size[i]; sz++)
           sztable[sz] = i;
       max_small_object_size = sz - 1;
