@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2002 Free Software Foundation, Inc.
+ * Copyright 2002, 2004 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -30,7 +30,7 @@
 #ifndef GST_ALLOC_H
 #define GST_ALLOC_H
 
-#define NUM_FREELISTS 45
+#define NUM_FREELISTS 47
 
 typedef struct heap_freeobj
 {
@@ -49,13 +49,13 @@ typedef struct heap_block
       int avail;		 /* Nr of objects available in block */
       struct heap_freeobj *free; /* Next free sub-block */
       struct heap_block *nfree;	 /* Next block on sub-freelist */
-      unsigned char data[1];
+      long double data[1];	 /* Give appropriate alignment */
     } small;
     struct {
       struct heap_block *next;	 /* Next block in freelist */
     } free;
     struct {
-      unsigned char data[1];
+      long double data[1];	 /* Give appropriate alignment */
     } large;
   } var;
 }
