@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -120,7 +120,7 @@ typedef union cparam_union
   PTR ptrVal;
   float floatVal;
   double doubleVal;
-  int valueVec[sizeof (double) / sizeof (int)];
+  long valueVec[sizeof (double) / sizeof (int)];
 }
 cparam_union;
 
@@ -211,8 +211,8 @@ static cfunc_info *c_func_root = NULL;
 
 /* The arguments as they are passed to push_obj. The first
    free argument is pointed to by c_arg. */
-static int c_arg_vec[ARG_VEC_SIZE];
-static int *c_arg;
+static long c_arg_vec[ARG_VEC_SIZE];
+static long *c_arg;
 
 /* The information on the char * parameters to be filled back on
    output from a callOut.  Again, sip is the first free item.
@@ -328,9 +328,12 @@ my_stat (const char *name,
 	 gst_stat * out)
 {
   int result;
-  static struct stat statOut;
+  struct stat statOut;
 
   result = stat (name, &statOut);
+  if (errno == EFAULT)
+    abort ();
+
   if (!result)
     {
       errno = 0;
@@ -896,13 +899,13 @@ push_obj (cparam_union * up,
   unsigned i;
   int alignInts;
 
-  alignInts = alignments[typ] / sizeof (int);
+  alignInts = alignments[typ] / sizeof (long);
 
   /* Align the stack properly */
   if ((c_arg - c_arg_vec) % alignInts)
     c_arg += alignInts - ((c_arg - c_arg_vec) % alignInts);
 
-  for (i = 0; i < type_sizes[typ] / sizeof (int); i++)
+  for (i = 0; i < type_sizes[typ] / sizeof (long); i++)
     {
       if (c_arg - c_arg_vec >= ARG_VEC_SIZE)
 	{
