@@ -34,6 +34,8 @@
 #ifndef GST_CINT_H
 #define GST_CINT_H
 
+/* Value of errno which is checked by the Smalltalk base classes.  */
+extern int _gst_errno;
 
 /* Element type for the name-to-C-function mapping table. */
 typedef void (*p_void_func) ();
@@ -83,5 +85,7 @@ extern OOP _gst_make_descriptor (OOP funcNameOOP,
 				 OOP returnTypeOOP,
 				 OOP argsOOP);
 
+/* Set the value of errno which is checked by Smalltalk to be errnum.  */
+extern void _gst_set_errno(int errnum);
 
 #endif /* GST_CINT_H */
