@@ -271,10 +271,6 @@ extern void _gst_compiled_method_at_put (OOP methodOOP,
 extern OOP _gst_compiled_method_at (OOP methodOOP,
 			   long int index);
 
-/* Sets the method descriptor of METHODOOP to be DESCRIPTOROOP. */
-extern void _gst_set_method_descriptor (OOP methodOOP,
-			      OOP descriptorOOP);
-
 /* Prepares the compiler for execution, initializing some variables. */
 extern void _gst_init_compiler (void);
 
@@ -288,13 +284,6 @@ extern OOP _gst_compile_method (tree_node method,
 				mst_Boolean returnLast,
 				mst_Boolean install);
 
-/* Returns the descriptor for the given CompiledMethod METHODOOP,
-   normally an instance of MethodInfo.  The descriptor contains
-   information about which category the method was stored under, and
-   information that can be used to reconstruct the source code for the
-   method. */
-extern OOP _gst_get_method_descriptor (OOP methodOOP) ATTRIBUTE_PURE;
-
 /* Constructs and returns a new CompiledMethod instance.  It computes
    the method header based on its arguments, and on the contents of
    the method's byte codes (setting up the flags to optimize returns).
