@@ -7,7 +7,8 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002 Free Software Foundation, Inc.
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003
+ * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
  * This file is part of GNU Smalltalk.
@@ -666,7 +667,6 @@ _gst_init_dictionary (void)
 
   init_runtime_objects ();
 
-  _gst_scavenge ();
   _gst_tenure_all_survivors ();
 }
 
@@ -1316,25 +1316,22 @@ _gst_find_shared_pool_variable (OOP poolOOP,
   if (is_a_kind_of (OOP_CLASS (poolOOP), _gst_class_class))
     poolOOP = _gst_class_variable_dictionary (poolOOP);
 
-  if (IS_NIL (poolOOP))
-    return _gst_nil_oop;
-
-  assocOOP = dictionary_association_at (poolOOP, symbol);
-  while (IS_NIL (assocOOP))
+  for (;;)
     {
+      if (!is_a_kind_of (OOP_CLASS (poolOOP), _gst_dictionary_class))
+        return (_gst_nil_oop);
+
+      assocOOP = dictionary_association_at (poolOOP, symbol);
+      if (!IS_NIL (assocOOP))
+	return (assocOOP);
+
       /* Try to find a super-namespace */
       if (!is_a_kind_of (OOP_CLASS (poolOOP), _gst_abstract_namespace_class))
 	return (_gst_nil_oop);
 
       pool = (gst_namespace) OOP_TO_OBJ (poolOOP);
       poolOOP = pool->superspace;
-      if (IS_NIL (poolOOP))
-	return (_gst_nil_oop);
-
-      /* Bring on the search in the super-namespace */
-      assocOOP = dictionary_association_at (poolOOP, symbol);
     }
-  return (assocOOP);
 }
 
 
