@@ -28,24 +28,8 @@
  *
  ***********************************************************************/
 
-#include "gst.h"
 #include "gstpriv.h"
 
-#include <poll.h>
-#include <errno.h>
-#include "signalx.h"
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#if defined(HAVE_SYS_TIME_H) || defined(TIME_WITH_SYS_TIME)
-# include <sys/time.h>
-#endif
-#if !defined(HAVE_SYS_TIME_H) || defined(TIME_WITH_SYS_TIME)
-# include <time.h>
-#endif
-
 
 /* This structure defines a list of pairs `struct pollfd'->semaphore
    which map each pollfd that is passed by the OS to the semaphore to
