@@ -1,4 +1,4 @@
-/* A Bison parser, made from /home/utente/devel-gst/libgst/genpr-parse.y, by GNU bison 1.49b.  */
+/* A Bison parser, made from /home/utente/devel-gst-stable/libgst/genpr-parse.y, by GNU bison 1.49b.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
@@ -1459,6 +1459,8 @@ gen_prim_id (const char *name, int id, const char *attrs)
   node->next = current_ids;
   current_ids = node;
 
+  prim_no++;
+
   filprintf (def_fil,
 	     "  _gst_primitive_table[%d].name = \"%s\";\n"
 	     "  _gst_primitive_table[%d].attributes = %s;\n"
@@ -1468,8 +1470,6 @@ gen_prim_id (const char *name, int id, const char *attrs)
 	     prim_no, attrs,
 	     prim_no, id,
 	     prim_no, current_func_name);
-
-  prim_no++;
 }
 
 int
@@ -1536,7 +1536,7 @@ output()
 	  "      _gst_primitive_table[i].func = VMpr_HOLE;\n"
 	  "    }\n"
 	  "}\n"
-	  "\n", proto, stmt, def, prim_no);
+	  "\n", proto, stmt, def, prim_no + 1);
 
   free (proto);
   free (stmt);
