@@ -563,6 +563,18 @@ typedef unsigned long long uint64_t;
    and this fools gcc's __attribute__ (format) */
 #include "snprintfv/printf.h"
 
+#undef obstack_init
+#define obstack_init(h)                                         \
+  _obstack_begin ((h), 0, LONG_DOUBLE_ALIGNMENT,                \
+                  (void *(*) (long)) obstack_chunk_alloc,       \
+                  (void (*) (void *)) obstack_chunk_free)
+
+#undef obstack_begin
+#define obstack_begin(h, size)                                  \
+  _obstack_begin ((h), (size), LONG_DOUBLE_ALIGNMENT,           \
+                  (void *(*) (long)) obstack_chunk_alloc,       \
+                  (void (*) (void *)) obstack_chunk_free)
+
 #include "oop.inl"
 #include "dict.inl"
 #include "interp.inl"
