@@ -10,7 +10,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003,2004
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -268,7 +268,7 @@ char *_gst_abort_execution = NULL;
 
 /* Set to true when some special action must be done at the next
    sequence point. */
-mst_Boolean _gst_except_flag;
+volatile mst_Boolean _gst_except_flag;
 
 /* Set to non-nil if a process must preempt the current one. */
 static OOP switch_to_process;
@@ -1234,7 +1234,7 @@ change_process_context (OOP newProcess)
   switch_to_process = _gst_nil_oop;
 
   /* save old context information */
-  if (ip)
+  if (!IS_NIL (_gst_this_context_oop))
     empty_context_stack ();
 
   /* printf("Switching to process %#O at priority %#O\n",
@@ -1286,6 +1286,10 @@ change_process_context (OOP newProcess)
   SET_THIS_METHOD (thisContext->method, GET_CONTEXT_IP (thisContext));
   sp = thisContext->contextStack + TO_INT (thisContext->spOffset);
 
+#if USE_JIT_TRANSLATION
+  ip = TO_INT (thisContext->ipOffset);
+#endif
+
   _gst_temporaries = thisContext->contextStack;
   _gst_self = thisContext->receiver;
 }
@@ -2207,7 +2211,7 @@ _gst_fixup_object_pointers (void)
 {
   gst_method_context thisContext;
 
-  if (ip)
+  if (!IS_NIL (_gst_this_context_oop))
     {
       /* Create real OOPs for the contexts here.  If we do it while copying,
          the newly created OOPs are in to-space and are never scanned! */
@@ -2241,7 +2245,7 @@ _gst_restore_object_pointers (void)
      and we also pick up the context to adjust sp and the temps
      accordingly. */
 
-  if (ip)
+  if (!IS_NIL (_gst_this_context_oop))
     {
       thisContext =
 	(gst_context_part) OOP_TO_OBJ (_gst_this_context_oop);
