@@ -244,8 +244,7 @@ static void init_paths (void);
 
 /* This routine scans the command line arguments, accumulating
    information and setting flags. */
-static int parse_args (int argc,
-		       char **argv);
+static int parse_args (int argc, char **argv);
 
 /* These functions load the per-user customization files, respectively
    .stinit (loaded at every startup) and .stpre (loaded before a local
@@ -791,7 +790,7 @@ parse_args (int argc,
 	    char **argv)
 {
   char **av = argv;
-  int ch, prev = 0, prevOptind = -1;
+  int ch, prev_optind = 0, minus_a_optind = -1;
 
 #ifndef USE_DYNAMIC_TRANSLATION
 # define OPTIONS "-acdDeEghHiI:K:lL:pQqrsSvVy"
@@ -803,31 +802,17 @@ parse_args (int argc,
   opterr = 1;
 
   while ((ch =
-	  getopt_long (argc, argv, OPTIONS, long_options, NULL)) != -1)
+	  getopt_long (argc, (char **) argv, OPTIONS, long_options, NULL)) != -1)
     {
 #undef OPTIONS
 
 #if DEBUG_GETOPT
-      printf ("%c \"%s\" %d     %c %d\n", ch, optarg ? optarg : "",
-	      optind, prev, prevOptind);
+      printf ("%c \"%s\" %d     %d\n", ch, optarg ? optarg : "",
+	      optind, minus_a_optind);
 #endif
 
-      if (prev == 'a' && ch == '\1')
-	{
-	  /* The first option after -a was not introduced by a minus,
-	     so getopt_long passed it to us as '\1'.  Undo the effect
-	     of this last getopt_long, so that this option is actually
-	     passed to Smalltalk. */
-	  optind--;
-	  break;
-	}
-
       switch (ch)
 	{
-	case '\1':
-	  *++av = optarg;
-	  break;
-
 	case 'c':
 	  _gst_make_core_file = true;
 	  break;
@@ -891,9 +876,10 @@ parse_args (int argc,
 	  /* "Officially", the C command line ends here.  The Smalltalk 
 	     command line, instead, starts right after the parameter
 	     containing -a. -a is handled specially by the code that
-	     tests the prev and prevOptind variables, so that ./gst -aI 
+	     tests the minus_a_optind variable, so that ./gst -aI 
 	     xxx yyy for example interprets xxx as the image to be
-	     loaded. */
+	     loaded.  */
+	  minus_a_optind = optind;
 	  break;
 
 	case 'I':
@@ -907,8 +893,9 @@ parse_args (int argc,
 
 	case 'K':
 	  {
-	    asprintf (++av, "%s/%s", _gst_image_file_default_path,
-		      optarg);
+	    char *file;
+	    asprintf (&file, "%s/%s", _gst_image_file_default_path, optarg);
+	    *++av = file;
 	    break;
 	  }
 
@@ -921,8 +908,13 @@ parse_args (int argc,
 		  IMAGE_PATH);
 	  return -1;
 
+	case '\1':
+	  *++av = optarg;
+	  break;
+
 	default:
-	  /* Fall through and show help message */
+	  printf (help_text);
+	  return 1;
 
 	case 'h':
 	case 'H':
@@ -931,25 +923,23 @@ parse_args (int argc,
 	  return -1;
 	}
 
-      if (prev != 'a')
+      if (minus_a_optind > -1)
 	{
-	  /* Track whether we have found a '-a' argument, by updating
-	     prev only until we find it. */
-	  prev = ch;
+	  /* If the first argument was not an option, undo and leave.  */
+	  if (ch == '\1')
+	    optind--;
 
+	  /* If the first argument after -a was not an option, or if there
+	     is nothing after -a, or if we finished processing the argument
+	     which included -a, leave.  */
+	  if (ch == '\1' || optind > prev_optind || optind > minus_a_optind)
+	    break;
 	}
-      else if (optind > prevOptind)
-	{
-	  /* We had found a '-a' argument and we ate all the remaining
-	     options in the element of argv that contained -a.  All the 
-	     remaining arguments are passed to Smalltalk. */
-	  break;
-	}
-      prevOptind = optind;
+      prev_optind = optind;
     }
 
   *++av = NULL;
-  if (prev == 'a')
+  if (minus_a_optind > -1)
     {
       _gst_smalltalk_passed_argc = argc - optind;
       _gst_smalltalk_passed_argv = argv + optind;
