@@ -856,7 +856,7 @@ int oldspace_sigsegv_handler (void* fault_address, int serious)
     }
 
   /* Try accessing the page */
-  (void) *(volatile OOP *) fault_address;
+  (void) *(volatile char *) fault_address;
   reentering = 0;
 
 #if defined (MMAN_DEBUGGING)
