@@ -103,11 +103,11 @@ typedef _uc		jit_insn;
 
 /*** ASSEMBLER ***/
 
-#define _OFF4(D)	(_UL(D) - _UL(_jit.pc))
-#define _CKD8(D)	_ck_d(8, ((_uc) _OFF4(D)) )
+#define _OFF4(D)        (_UL(D) - _UL(_jit.x.pc))
+#define _CKD8(D)        _ck_d(8, ((_uc) _OFF4(D)) )
 
-#define _D8(D)		(_B(0), ((*(_PUC(_jit.pc)-1))= _CKD8(D)))
-#define _D32(D)		(_L(0), ((*(_PUL(_jit.pc)-1))= _OFF4(D)))
+#define _D8(D)          (_B(0), ((*(_PUC(_jit.x.pc)-1))= _CKD8(D)))
+#define _D32(D)         (_L(0), ((*(_PUL(_jit.x.pc)-1))= _OFF4(D)))
 
 #ifndef _ASM_SAFETY
 # define _M(M)		(M)
