@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002 Free Software Foundation, Inc.
+ * Copyright 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU lightning.
@@ -23,7 +23,7 @@
  * License for more details.
  * 
  * You should have received a copy of the GNU Lesser General Public License
- * along with GNU lightning; see the file COPYING.LIB; if not, write to the
+ * along with GNU lightning; see the file COPYING.LESSER; if not, write to the
  * Free Software Foundation, 59 Temple Place - Suite 330, Boston,
  * MA 02111-1307, USA.
  *
@@ -38,21 +38,13 @@
 #error Go get GNU C, I do not know how to flush the cache
 #error with this compiler.
 #else
-/* Why doesn't this compile?!?
- * static void
- * jit_flush_code(start, end)
- *      void 	*start;
- *      void	*end;
- */
-
 static void
-jit_flush_code(void* start, void* end)
+jit_flush_code(void *start, void *end)
 {
 #ifndef LIGHTNING_CROSS
-  static int cache_line_size, cache_line_shift;
   register char *ddest, *idest;
-  register int n, dcache_lines, icache_lines;
 
+  static int cache_line_size;
   if (cache_line_size == 0) {
     char buffer[8192];
     int i, probe;
@@ -68,29 +60,28 @@ jit_flush_code(void* start, void* end)
 
     /* i is now just before the start of the cache line */
     i++;
-    for(cache_line_shift = 0, cache_line_size = 1; 
-	 i + cache_line_size < 8192; cache_line_shift++, cache_line_size <<= 1)
+    for(cache_line_size = 1; i + cache_line_size < 8192; cache_line_size <<= 1)
       if (buffer[i + cache_line_size] != 0x00)
         break;
   }
 
-  n = ((char *) end) - ((char *)start);
-  dcache_lines = icache_lines = (n + cache_line_size - 1) >> cache_line_shift;
+  start -= ((long) start) & (cache_line_size - 1);
+  end -= ((long) end) & (cache_line_size - 1);
 
   /* Force data cache write-backs */
-  for (ddest = start; dcache_lines--; ddest += cache_line_size) {
+  for (ddest = start; ddest <= (char *) end; ddest += cache_line_size) {
     __asm__ __volatile__ ("dcbst 0,%0" : : "r"(ddest));
   }
   __asm__ __volatile__ ("sync" : : );
 
   /* Now invalidate the instruction cache */
-  for (idest = start; icache_lines--; idest += cache_line_size) {
-    __asm__ __volatile__ ("icbi 0,%0; isync" : : "r"(idest));
+  for (idest = start; idest <= (char *) end; idest += cache_line_size) {
+    __asm__ __volatile__ ("icbi 0,%0" : : "r"(idest));
   }
   __asm__ __volatile__ ("isync" : : );
-#endif
+#endif /* !LIGHTNING_CROSS */
 }
-#endif
+#endif /* __GNUC__ || __GNUG__ */
 
 #define _jit (*jit)
 
@@ -110,15 +101,19 @@ _jit_trampoline(jit, n)
 {
   static jit_insn	trampolines[200];
   static jit_insn	*p_trampolines[6], *free = trampolines;
-  register int		i, ofs, frame_size;
+  jit_insn		*trampo;
+  int			i, ofs, frame_size;
 
   if (!p_trampolines[n]) {
-    _jit.pc = p_trampolines[n] = free;
+    _jit.x.pc = trampo = p_trampolines[n] = free;
+
+    frame_size = 24 + (6 + n) * 4;	/* r26..r31 + args		   */
+    frame_size += 15;			/* the stack must be quad-word     */
+    frame_size &= ~15;			/* aligned			   */
 
-    frame_size = 8 + (6 + n) * 4;	/* r26..r31 + args		   */
     STWUrm(1, -frame_size, 1);		/* stwu  r1, -x(r1)		   */
 
-    for (ofs = 8, i = 26 - n; i <= 31; ofs += 4, i++) {
+    for (ofs = frame_size - (6 + n) * 4, i = 26 - n; i <= 31; ofs += 4, i++) {
       STWrm(i, ofs, 1);			/* stw   rI, ofs(r1)		   */
     }
     STWrm(0, ofs+4, 1);			/* stw   r0, x(r1)		   */
@@ -129,14 +124,14 @@ _jit_trampoline(jit, n)
     LWZrm(0, ofs+4, 1);			/* lwz   r0, x(r1)  (ret.addr.)    */
     MTLRr(0);				/* mtspr LR, r0			   */
 
-    for (ofs = 8, i = 26 - n; i <= 31; ofs += 4, i++) {
+    for (ofs = frame_size - (6 + n) * 4, i = 26 - n; i <= 31; ofs += 4, i++) {
       LWZrm(i, ofs, 1);			/* lwz   rI, ofs(r1)		   */
     }
     ADDIrri(1, 1, frame_size);		/* addi  r1, r1, x		   */
     BLR();				/* blr				   */
 
-    jit_flush_code(p_trampolines[n], _jit.pc);
-    free = _jit.pc;
+    jit_flush_code(trampo, _jit.x.pc);
+    free = _jit.x.pc;
   }
 
   return p_trampolines[n];
@@ -149,9 +144,9 @@ _jit_prolog(jit, n)
 {
   register jit_insn	*save_pc, *trampo;
 
-  save_pc = _jit.pc;
+  save_pc = _jit.x.pc;
   trampo = _jit_trampoline(jit, n);
-  _jit.pc = save_pc;
+  _jit.x.pc = save_pc;
 
   _jitl.nextarg_get = 25;
   MFLRr(0);
