@@ -1,5 +1,5 @@
 /* Fault handler information.  Linux/HPPA version.
-   Copyright (C) 2002  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2002-2003  Bruno Haible <bruno@clisp.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,20 +15,13 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#include <siginfo.h>
 #include <ucontext.h>
 
 #define SIGSEGV_FAULT_HANDLER_ARGLIST  int sig, siginfo_t *sip, void *ucp
-#define SIGSEGV_FAULT_ADDRESS  sip->si_addr
-#define SIGSEGV_FAULT_CONTEXT  ((ucontext_t *) ucp)
-#define SIGSEGV_FAULT_STACKPOINTER  ((ucontext_t *) ucp)->uc_mcontext.gregs.g_regs[30]
+#define SIGSEGV_FAULT_ADDRESS  sip->si_ptr
+#define SIGSEGV_FAULT_ADDRESS_FROM_SIGINFO
 
 #if 0
-
-#include <asm/sigcontext.h>
-
-#define SIGSEGV_FAULT_HANDLER_ARGLIST  int sig, ... scp
-#define SIGSEGV_FAULT_CONTEXT  scp
-#define SIGSEGV_FAULT_STACKPOINTER  scp->sc_gr[30]
-
+#define SIGSEGV_FAULT_CONTEXT  ((ucontext_t *) ucp)
+#define SIGSEGV_FAULT_STACKPOINTER  ((ucontext_t *) ucp)->uc_mcontext.gregs.g_regs[30]
 #endif
