@@ -1,3 +1,4 @@
+#line 1 "./dl.in"
 /*  -*- Mode: C -*-  */
 
 /* ltdl.c --- dynamic loading header file for Snprintfv
@@ -36,5 +37,7 @@
  * None, but exits with an error code of %EXIT_FAILURE if there
  * is an error.
  */
-extern void snv_load_all_modules PARAMS(());
+extern void snv_load_all_modules (void);
 
+
+#line 31 "./dl.in"
