@@ -57,7 +57,7 @@
 static snv_long_double modfl (long double x, long double *exp);
 #  endif
 #  ifndef HAVE_COPYSIGNL
-static snv_long_double copysignl (long double x, long double y)
+static snv_long_double copysignl (long double x, long double y);
 #  endif
 # else
 #  ifdef HAVE_ISNAN
